==> eric_4.5.8.orig.tar.gz: eric4-4.5.8/eric/Helpviewer/AdBlock/AdBlockBlockedNetworkReply.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2009 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing a QNetworkReply subclass reporting a blocked request.
"""

from PyQt4.QtCore import *
from PyQt4.QtNetwork import QNetworkReply, QNetworkAccessManager

class AdBlockBlockedNetworkReply(QNetworkReply):
    """
    Class implementing a QNetworkReply subclass reporting a blocked request.
    """
    def __init__(self, request, rule, parent = None):
        """
        Constructor
        
        @param request reference to the request object (QNetworkRequest)
        @param fileData reference to the data buffer (QByteArray)
        @param mimeType for the reply (string)
        """
        QNetworkReply.__init__(self, parent)
        self.setOperation(QNetworkAccessManager.GetOperation)
        self.setRequest(request)
        self.setUrl(request.url())
        self.setError(QNetworkReply.ContentAccessDenied, 
                      self.trUtf8("Blocked by AdBlock rule: %1.").arg(rule.filter()))
        QTimer.singleShot(0, self.__fireSignals)
    
    def __fireSignals(self):
        """
        Private method to send some signals to end the connection.
        """
        self.emit(SIGNAL("error(QNetworkReply::NetworkError)"), 
                         QNetworkReply.ContentAccessDenied)
        self.emit(SIGNAL("finished()"))
    
    def readData(self, maxlen):
        """
        Protected method to retrieve data from the reply object.
        
        @param maxlen maximum number of bytes to read (integer)
        @return string containing the data (string)
        """
        return None
    
    def abort(self):
        """
        Public slot to abort the operation.
        """
        # do nothing
        pass

==> eric5-5.3.6.tar.gz: eric5-5.3.6/eric/Helpviewer/AdBlock/AdBlockBlockedNetworkReply.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2009 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing a QNetworkReply subclass reporting a blocked request.
"""

from PyQt4.QtCore import QTimer
from PyQt4.QtNetwork import QNetworkReply, QNetworkAccessManager


class AdBlockBlockedNetworkReply(QNetworkReply):
    """
    Class implementing a QNetworkReply subclass reporting a blocked request.
    """
    def __init__(self, request, subscription, rule, parent=None):
        """
        Constructor
        
        @param request reference to the request object (QNetworkRequest)
        @param subscription subscription containing the matched rule (AdBlockSubscription)
        @param rule matching rule (AdBlockRule)
        @param parent reference to the parent object (QObject)
        """
        super().__init__(parent)
        self.setOperation(QNetworkAccessManager.GetOperation)
        self.setRequest(request)
        self.setUrl(request.url())
        self.setError(QNetworkReply.ContentAccessDenied,
                      "AdBlockRule:{0} ({1})".format(subscription.title(), rule.filter()))
        QTimer.singleShot(0, self.__fireSignals)
    
    def __fireSignals(self):
        """
        Private method to send some signals to end the connection.
        """
        self.error[QNetworkReply.NetworkError].emit(QNetworkReply.ContentAccessDenied)
        self.finished.emit()
    
    def readData(self, maxlen):
        """
        Protected method to retrieve data from the reply object.
        
        @param maxlen maximum number of bytes to read (integer)
        @return string containing the data (string)
        """
        return None
    
    def abort(self):
        """
        Public slot to abort the operation.
        """
        # do nothing
        pass
